@@ -1,18 +1,19 @@
 import logging
 
-from .views import IndexView
-from filters import TemplateFilters
 from flask import Blueprint, url_for
 from flask.ext.babelpkg import gettext as _gettext, lazy_gettext
 from flask.ext.appbuilder.babel.manager import BabelManager
 from flask.ext.appbuilder import translations
 from flask.ext.appbuilder import Base
+from .views import IndexView
+from .filters import TemplateFilters
+from .menu import Menu
 from .security.manager import SecurityManager
-from menu import Menu
 
 log = logging.getLogger(__name__)
 
 
+
 class BaseApp(object):
     """
         This is the base class for the all framework.
@@ -132,7 +133,7 @@ class BaseApp(object):
         self.sm.register_views(self)
 
     def _init_view_session(self, baseview_class):
-        if baseview_class.datamodel.session == None:
+        if baseview_class.datamodel.session is None:
             baseview_class.datamodel.session = self.db.session
         return baseview_class()
 
