@@ -13,9 +13,9 @@ from flask_babelpkg import lazy_gettext as _
 
 from flask_appbuilder import Base
 
-from models import User, Role, PermissionView, Permission, ViewMenu, \
+from .models import User, Role, PermissionView, Permission, ViewMenu, \
     assoc_permissionview_role
-from views import AuthDBView, AuthOIDView, ResetMyPasswordView, AuthLDAPView, \
+from .views import AuthDBView, AuthOIDView, ResetMyPasswordView, AuthLDAPView, \
     ResetPasswordView, UserDBGeneralView, UserLDAPGeneralView, UserOIDGeneralView, RoleGeneralView, \
     PermissionViewGeneralView, ViewMenuGeneralView, PermissionGeneralView, UserStatsChartView
 
@@ -110,7 +110,7 @@ class SecurityManager(object):
         g.user = current_user
 
     def migrate_get_new_obj(self, old_obj, new_obj):
-        for col in old_obj.keys():
+        for col in list(old_obj.keys()):
             setattr(new_obj, col, getattr(old_obj, col))
         return new_obj
 
@@ -137,7 +137,7 @@ class SecurityManager(object):
         engine = self.session.get_bind(mapper=None, clause=None)
         inspector = Inspector.from_engine(engine)
         if 'user' in inspector.get_table_names() and 'role' in inspector.get_table_names() and 'permission' in inspector.get_table_names():
-            print "Found previous security tables, migrating..."
+            log.info("Found previous security tables, migrating...")
 
             metadata = MetaData(engine)
 
@@ -148,22 +148,22 @@ class SecurityManager(object):
             old_view_menu = Table('view_menu', metadata, autoload=True)
             old_permission_view_role = Table('permission_view_role', metadata, autoload=True)
 
-            print "Migrating Views and Menus"
+            log.info("Migrating Views and Menus")
             self.migrate_obj(old_view_menu, ViewMenu)
 
-            print "Migrating Permissions"
+            log.info("Migrating Permissions")
             self.migrate_obj(old_permission, Permission)
 
-            print "Migrating Permissions on Views"
+            log.info("Migrating Permissions on Views")
             self.migrate_obj(old_permission_view, PermissionView)
 
-            print "Migrating Roles"
+            log.info("Migrating Roles")
             self.migrate_obj(old_role, Role)
 
-            print "Migrating Roles to Permissions on Views"
+            log.info("Migrating Roles to Permissions on Views")
             self.migrate_obj(old_permission_view_role, self.quick_mapper(assoc_permissionview_role))
 
-            print "Migrating Users"
+            log.info("Migrating Users")
             self.migrate_obj(old_user, User)
 
 
@@ -253,8 +253,8 @@ class SecurityManager(object):
                 except ldap.INVALID_CREDENTIALS:
                     self._update_user_auth_stat(user, False)
                     return None
-            except ldap.LDAPError, e:
-                if type(e.message) == dict and e.message.has_key('desc'):
+            except ldap.LDAPError as e:
+                if type(e.message) == dict and 'desc' in e.message:
                     log.error("LDAP Error {0}".format(e.message['desc']))
                     return None
                 else:
